Crate lineargen

Crate lineargen 

Lineargen

rand compatible pseudorandom generators based on linear feedback shift registers (LFSR).

Bit sequence generators of that type are extremely fast and have a small memory footprint. However, they might not always have ideal statistical properties.

Do not use them for cryptographical purposes.

Modules

large
This module contains the Linear128 LFSR with a period of 2128-1.

Structs

Linear16
16-bit Galois linear feedback shift register. This generator has an extremely short period of 65535.
Linear32
32-bit Galois linear feedback shift register. Period length is 232-1.
Linear64
64-bit Galois linear feedback shift register. Period length is 264-1.